cli.patch

cli.patch

CLI commands for syncweaver patch lifecycle operations.

Functions

Name Description
annotate_rejected_cmd Record rejected patch metadata in lockfile extension fields.
create_cmd Create or update a canonical patch file for a
list_cmd List tracked patch file records for a source path.
patch_group Create, annotate, and list source patch artifacts.

annotate_rejected_cmd

cli.patch.annotate_rejected_cmd(patch_path, pr_url, reason, lockfile)

Record rejected patch metadata in lockfile extension fields.

create_cmd

cli.patch.create_cmd(source_path, repo_url, lockfile, patch_dir)

Create or update a canonical patch file for a tracked source path.

list_cmd

cli.patch.list_cmd(source_path, lockfile)

List tracked patch file records for a source path.

patch_group

cli.patch.patch_group()

Create, annotate, and list source patch artifacts.