cli.add
cli.add
CLI command for adding an external repository to a host repository.
Functions
| Name | Description |
|---|---|
| add_cmd | Add an external repository to the current host repository. |
| add_external_repository | Add an external repository and register it in .syncweaver-lock.json. |
add_cmd
cli.add.add_cmd(
destination_path,
repo_url,
ref,
remote_subdir,
lockfile,
overwrite,
)Add an external repository to the current host repository.
add_external_repository
cli.add.add_external_repository(
destination_path,
repo_url,
ref,
remote_subdir,
lockfile_path,
overwrite,
)Add an external repository and register it in .syncweaver-lock.json.