git

git

Git command helpers shared across syncweaver modules.

Functions

Name Description
run_git Run a git command and return stdout, raising RuntimeError on failure.

run_git

git.run_git(args, cwd=None)

Run a git command and return stdout, raising RuntimeError on failure.